@@ -373,7 +373,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `system` WRITE;
 /*!40000 ALTER TABLE `system` DISABLE KEYS */;
-INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,106,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30);
+INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,108,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30);
 /*!40000 ALTER TABLE `system` ENABLE KEYS */;
 UNLOCK TABLES;
 
@@ -381,13 +381,15 @@ CREATE TABLE IF NOT EXISTS `auto_simulation` (
   `id` int(11) NOT NULL auto_increment,
   `name` varchar(64) character set utf8 NOT NULL,
   `disable` tinyint(1) NOT NULL default '0',
-  `dial_num` varchar(256) NOT NULL,
+  `dial_num` varchar(4000) NOT NULL,
   `period_min` int(11) NOT NULL,
   `period_max` int(11) NOT NULL,
   `talk_time_min` int(11) NOT NULL,
   `talk_time_max` int(11) NOT NULL,
   `next_time` datetime NOT NULL,
   `last_time` datetime NOT NULL,
+  `period_type` int(11) NOT NULL default '0',
+  `period_setting` varchar(2000) NOT NULL,
   PRIMARY KEY  (`id`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 
@@ -398,9 +400,11 @@ CREATE TABLE IF NOT EXISTS `imei_db` (
   `sim_name` int(11) NOT NULL default '0',
   `used` int(11) NOT NULL default '0',
   `used_time` datetime NOT NULL,
+  `imsi` varchar(32) NOT NULL,
   PRIMARY KEY  (`id`),
   KEY `sim_name` (`sim_name`),
-  KEY `used` (`used`)
+  KEY `used` (`used`),
+  KEY `imsi` (`imsi`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 
 --
