@@ -315,6 +315,18 @@
   KEY `used` (`used`)
 ) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;");
 
+/*2015-3-26 18:50:52 */
+	if(!$rs || $rs[0] < 107){
+		@$db->updatequery("update `system` set `version`='108'");
+		@$db->updatequery("ALTER TABLE `imei_db` ADD `imsi` varchar(32) NOT NULL");
+		@$db->updatequery("ALTER TABLE `imei_db` ADD INDEX (`imsi`)");
+	}
+
+/*1.6.1 */
+	@$db->updatequery("ALTER TABLE  `auto_simulation` CHANGE  `dial_num`  `dial_num` VARCHAR( 4000 ) CHARACTER SET latin1 COLLATE latin1_swedish_ci NOT NULL");
+	@$db->updatequery("ALTER TABLE  `auto_simulation` ADD `period_type` int(11) NOT NULL default '0'");
+	@$db->updatequery("ALTER TABLE  `auto_simulation` ADD `period_setting` varchar(2000) NOT NULL");
+	
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 
